==> paraview_5.4.1+dfsg4.orig.tar.xz: paraview-5.4.1+dfsg4/Qt/ApplicationComponents/pqPropertyGroupButton.h <==
/*=========================================================================

   Program: ParaView
   Module: pqPropertyGroupButton.h

   Copyright (c) 2005-2012 Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

#ifndef _pqPropertyGroupButton_h
#define _pqPropertyGroupButton_h

#include "pqApplicationComponentsModule.h"
#include "pqPropertyGroupWidget.h"

class QDialog;

class PQAPPLICATIONCOMPONENTS_EXPORT pqPropertyGroupButton : public pqPropertyGroupWidget
{
  Q_OBJECT

public:
  pqPropertyGroupButton(vtkSMProxy* proxy, vtkSMPropertyGroup* smGroup, QWidget* parent = 0);

  // This object takes ownership of the 'dialog' parameter and deletes it when
  // the object is deleted. Note QDialog destructor is virtual so memory is
  // property deleted.
  void SetEditor(QDialog* dialog) { this->Editor = dialog; }
  ~pqPropertyGroupButton();

private slots:
  void showEditor();

private:
  QDialog* Editor;
};

#endif

==> paraview_5.7.0.orig.tar.xz: paraview-5.7.0/Qt/ApplicationComponents/pqPropertyGroupButton.h <==
/*=========================================================================

   Program: ParaView
   Module: pqPropertyGroupButton.h

   Copyright (c) 2005-2012 Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

#ifndef _pqPropertyGroupButton_h
#define _pqPropertyGroupButton_h

#include "pqApplicationComponentsModule.h"
#include "pqPropertyGroupWidget.h"

class QDialog;

class PQAPPLICATIONCOMPONENTS_EXPORT pqPropertyGroupButton : public pqPropertyGroupWidget
{
  Q_OBJECT

public:
  pqPropertyGroupButton(vtkSMProxy* proxy, vtkSMPropertyGroup* smGroup, QWidget* parent = 0);

  // This object takes ownership of the 'dialog' parameter and deletes it when
  // the object is deleted. Note QDialog destructor is virtual so memory is
  // property deleted.
  void SetEditor(QDialog* dialog) { this->Editor = dialog; }
  ~pqPropertyGroupButton() override;

private slots:
  void showEditor();

private:
  QDialog* Editor;
};

#endif
